leaftools.remove_leaf_and_shrink_durated_parent_containers
==========================================================

.. autofunction:: abjad.tools.leaftools.remove_leaf_and_shrink_durated_parent_containers.remove_leaf_and_shrink_durated_parent_containers
